changeset 11746:e93b5c05c949

(main): Increase lock timeout to five minutes.
author Richard M. Stallman <rms@gnu.org>
date Sun, 07 May 1995 22:36:27 +0000
parents 1136a3614d79
children afc9c0b4fbb5
files lib-src/movemail.c
diffstat 1 files changed, 5 insertions(+), 2 deletions(-) [+]
line wrap: on
line diff
--- a/lib-src/movemail.c	Sun May 07 22:29:15 1995 +0000
+++ b/lib-src/movemail.c	Sun May 07 22:36:27 1995 +0000
@@ -251,11 +251,14 @@
 	break;
       sleep (1);
 
-      /* If lock file is a minute old, unlock it.  */
+      /* If lock file is five minutes old, unlock it.
+	 Five minutes should be good enough to cope with crashes
+	 and wedgitude, and long enough to avoid being fooled
+	 by time differences between machines.  */
       if (stat (lockname, &st) >= 0)
 	{
 	  now = time (0);
-	  if (st.st_ctime < now - 60)
+	  if (st.st_ctime < now - 300)
 	    unlink (lockname);
 	}
     }